==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chino</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospacial</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desactivar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro caído</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Instalouse a mesma versión</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro caído</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Este tipo de letra non estará dispoñible para os aplicativos</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estes tipos de letra non estarán dispoñibles para os aplicativos</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Non se poden eliminar os outros tipos de letra do sistema %1</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Non se pode eliminar a letra &quot;% 1&quot; en uso</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Non se poden eliminar os outros tipos de letra do sistema% 1 e a fonte &quot;% 2&quot; en uso</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Está seguro de que desexa eliminar % 1 fonte (s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Eliminando fontes, agarde ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación da fonte</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Non hai fontes a instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Don&apos;t let your dreams be dreams</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca rexistrada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Xestor de fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Xestor de fontes axuda aos usuarios a instalar e administrar fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando fontes, agarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>O tipo de letra exportado ao escritorio</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>% 1 fontes exportadas ao escritorio</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Erro ao exportar 1 tipo de letra. Non hai espazo de disco suficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Erro ao exportar fontes %1. Non hai espazo de disco suficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Engadir fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar o xestor de ficheiros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Desactiváronse as fontes</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>% 1 está en uso, polo que non pode deshabilitalo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Non podes desactivar as fontes do sistema e as fontes en uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Non podes desactivar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro caído</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non instalado</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Non hai fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Páxina enriba</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Páxina abaixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Engadir fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Información da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Insira o texto anterior</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chino</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospacial</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desactivar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro caído</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Instalouse a mesma versión</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Este tipo de letra non estará dispoñible para os aplicativos</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estes tipos de letra non estarán dispoñibles para os aplicativos</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Non se poden eliminar os outros tipos de letra do sistema %1</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Non se pode eliminar a letra &quot;% 1&quot; en uso</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Non se poden eliminar os outros tipos de letra do sistema% 1 e a fonte &quot;% 2&quot; en uso</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Está seguro de que desexa eliminar % 1 fonte (s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Eliminando fontes, agarde ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación da fonte</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Non hai fontes a instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca rexistrada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Xestor de fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Xestor de fontes axuda aos usuarios a instalar e administrar fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando fontes, agarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>O tipo de letra exportado ao escritorio</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>% 1 fontes exportadas ao escritorio</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Erro ao exportar 1 tipo de letra. Non hai espazo de disco suficiente.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Erro ao exportar fontes %1. Non hai espazo de disco suficiente.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Engadir fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar o xestor de ficheiros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Desactiváronse as fontes</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>% 1 está en uso, polo que non pode deshabilitalo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Non podes desactivar as fontes do sistema e as fontes en uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Non podes desactivar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro caído</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non instalado</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Non hai fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Páxina enriba</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Páxina abaixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Engadir fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Información da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Insira o texto anterior</translation>
    </message>
</context>
</TS>
